#! /usr/bin/env ruby
# -*- coding: utf-8 -*-
# 
# Taker が作成し出力した更新用ウィキテキストで、全言語版の統計ページを更新します。
# 更新用ウィキテキストのファイル名は、作業ディレクトリの<tt>new-page.txt</tt> です。
# 更新が正常に行われた場合、終了ステータス 0 を返します。
# なんらかの原因で正常に行われなかった場合、終了ステータスとして 0 以外を返します。
# 

require './languages-statistics'

$stderr.puts 'Console encoding set in config.xml: ' + WikiBotConfig.new.console_encoding
processor = Updater.new
processor.execute
exit(processor.status)

